Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1384)

Unified Diff: chrome/test/data/android/payments/contact_details_and_free_shipping.js

Issue 2182123003: [Payments] Add information requested by merchant metrics to PR. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/test/data/android/payments/contact_details_and_free_shipping.js
diff --git a/chrome/test/data/android/payments/free_shipping.js b/chrome/test/data/android/payments/contact_details_and_free_shipping.js
similarity index 82%
copy from chrome/test/data/android/payments/free_shipping.js
copy to chrome/test/data/android/payments/contact_details_and_free_shipping.js
index dab9949c1c36e4e52bb102e1cc229aafdb191873..c5fc1bee96f69b26e599a4fc472f878196dbb366 100644
--- a/chrome/test/data/android/payments/free_shipping.js
+++ b/chrome/test/data/android/payments/contact_details_and_free_shipping.js
@@ -8,7 +8,8 @@
/* global toDictionary:false */
/**
* Launches the PaymentRequest UI that offers free shipping worldwide.
*/
function buy() { // eslint-disable-line no-unused-vars
try {
@@ -22,12 +23,14 @@ function buy() { // eslint-disable-line no-unused-vars
selected: true
}]
},
- {requestShipping: true});
+ {requestPayerEmail: true, requestPayerPhone: true,
+ requestShipping: true});
request.show()
.then(function(resp) {
resp.complete('success')
.then(function() {
print(
+ resp.payerEmail + '<br>' + resp.payerPhone + '<br>' +
resp.shippingOption + '<br>' +
JSON.stringify(
toDictionary(resp.shippingAddress), undefined, 2) +
@@ -8,7 +8,8 @@
/* global toDictionary:false */
/**
- * Launches the PaymentRequest UI that offers free shipping worldwide.
+ * Launches the PaymentRequest UI that requests an email address and a phone
+ * number and offers free shipping worldwide.
*/
function buy() { // eslint-disable-line no-unused-vars

Powered by Google App Engine
This is Rietveld 408576698